==> foundation-ui-components-1.15.0.tgz: package/src/common/carousal/specs/NsScrollingCarousal.spec.tsx <==
import { render, screen, fireEvent } from '@/test-utils/index';
import { NsScrollingCarousal } from '@/common/';

const mockEntries = [
    { id: 1, title: 'First entry' },
    { id: 2, title: 'Second entry' },
    { id: 3, title: 'Third entry' },
    { id: 4, title: 'Fourth entry' },
    { id: 5, title: 'Fifth entry' },
];

const mockRenderEntry = (entry: any, index: number) => {
    return <div key={index}>{entry.title}</div>;
};
const mockSettings = {
    slidesToShow: 2,
    slidesToScroll: 1,
};
const testId = 'scrolling-carousal';
describe('NsScrollingCarousal', () => {
    it('should have slides', () => {
        render(
            <NsScrollingCarousal
                slides={mockEntries}
                renderSlide={mockRenderEntry}
                settings={mockSettings}
                scrollSeconds={1}
                stillSeconds={9}
                additionalProps={{
                    testid: testId,
                }}
            />
        );
        const el = screen.getAllByText(mockEntries[0].title);
        expect(el).toHaveLength(2);
    });

    it('should change slides when clicking on prev or next buttons', () => {
        const { container } = render(
            <NsScrollingCarousal
                slides={mockEntries}
                renderSlide={mockRenderEntry}
                settings={mockSettings}
                scrollSeconds={1}
                stillSeconds={9}
            />
        );

        let currentSlide = container.querySelector('.slick-slide.slick-current');
        expect(currentSlide!.attributes['data-index' as any].value).toEqual('0');

        /* this is library's button, not our button, it is used for changing slides,
      clicking svg is not making any slide change in this test */
        const nextButton = screen.getByRole('button', { name: /next/i });
        fireEvent.click(nextButton);

        let slickTrack = container.querySelector('.slick-track');
        currentSlide = slickTrack!.querySelector('.slick-slide.slick-current');
        expect(currentSlide!.attributes['data-index' as any].value).toEqual('1');
    });
});

==> foundation-ui-components-1.30.1.tgz: package/src/common/carousal/specs/NsScrollingCarousal.spec.tsx <==
import { ReactElement } from 'react';

import { NsScrollingCarousal } from '@/common/';
import { fireEvent, render, screen } from '@/test-utils/index';

const mockEntries = [
    { id: 1, title: 'First entry' },
    { id: 2, title: 'Second entry' },
    { id: 3, title: 'Third entry' },
    { id: 4, title: 'Fourth entry' },
    { id: 5, title: 'Fifth entry' },
];

const mockRenderEntry = (entry: any, index: number): ReactElement => {
    return <div key={index}>{entry.title}</div>;
};
const mockSettings = {
    slidesToShow: 2,
    slidesToScroll: 1,
};
const testId = 'scrolling-carousal';
describe('NsScrollingCarousal', () => {
    it('should have slides', () => {
        render(
            <NsScrollingCarousal
                slides={mockEntries}
                renderSlide={mockRenderEntry}
                settings={mockSettings}
                scrollSeconds={1}
                stillSeconds={9}
                additionalProps={{
                    testid: testId,
                }}
            />
        );
        const el = screen.getAllByText(mockEntries[0].title);
        expect(el).toHaveLength(2);
    });

    it('should change slides when clicking on prev or next buttons', () => {
        const { container } = render(
            <NsScrollingCarousal
                slides={mockEntries}
                renderSlide={mockRenderEntry}
                settings={mockSettings}
                scrollSeconds={1}
                stillSeconds={9}
            />
        );

        let currentSlide = container.querySelector('.slick-slide.slick-current');
        expect(currentSlide!.attributes['data-index' as any].value).toEqual('0');

        /* this is library's button, not our button, it is used for changing slides,
      clicking svg is not making any slide change in this test */
        const nextButton = screen.getByRole('button', { name: /next/i });
        fireEvent.click(nextButton);

        let slickTrack = container.querySelector('.slick-track');
        currentSlide = slickTrack!.querySelector('.slick-slide.slick-current');
        expect(currentSlide!.attributes['data-index' as any].value).toEqual('1');
    });
});
